.. _oep0003:

===========================================
OEP-0003: Surface mass balance enhancements
===========================================

:Authors: Fabien Maussion
:Status: Work in progress
:Created: 28.08.2019
:Updated: 01.04.2022


Abstract
--------

This document used to contain a list of recommendations to improve the
OGGM mass balance models. This discussion has now been moved to github:
https://github.com/OGGM/massbalance-sandbox
